package com.jiuqi.util.chinese;

import java.io.Serializable;

/* loaded from: com_jiuqi_util_chinese.jar:com/jiuqi/util/chinese/ChineseDigit.class */
class ChineseDigit implements Comparable, Cloneable, Serializable {
    private static final char[] SMALL_DIGITS = {9675, 19968, 20108, 19977, 22235, 20116, 20845, 19971, 20843, 20061};
    private static final char[] BIG_DIGITS = {38646, 22777, 36144, 21441, 32902, 20237, 38470, 26578, 25420, 29590};
    private static char bufferedChar = 0;
    private static int bufferedValue = -1;
    private int digit;

    public ChineseDigit() {
        this.digit = 0;
    }

    public ChineseDigit(int dig) {
        if (dig >= 0 && dig <= 9) {
            this.digit = dig;
            return;
        }
        throw new IllegalArgumentException("只能从0-9的阿拉伯数字来建立对象！");
    }

    public ChineseDigit(char digChar) throws NotValidChineseDigitException {
        int value = digChar - '0';
        if (value >= 0 && value <= 9) {
            this.digit = value;
        } else {
            this.digit = valueOf(digChar);
        }
    }

    public int intValue() {
        return this.digit;
    }

    public char chineseValue(boolean useBigChar) {
        return toChineseChar(this.digit, useBigChar);
    }

    public static int valueOf(char chDig) throws NotValidChineseDigitException {
        if (bufferedChar == chDig) {
            return bufferedValue;
        }
        int position = -1;
        int i = 0;
        while (true) {
            if (i >= SMALL_DIGITS.length) {
                break;
            }
            if (chDig != SMALL_DIGITS[i]) {
                i++;
            } else {
                position = i;
                break;
            }
        }
        if (position != -1) {
            bufferedChar = chDig;
            bufferedValue = position;
            return position;
        }
        int i2 = 0;
        while (true) {
            if (i2 >= BIG_DIGITS.length) {
                break;
            }
            if (chDig != BIG_DIGITS[i2]) {
                i2++;
            } else {
                position = i2;
                break;
            }
        }
        if (position != -1) {
            bufferedChar = chDig;
            bufferedValue = position;
            return position;
        }
        throw new NotValidChineseDigitException("字符\"" + chDig + "\"不是一个中文的数字字符！");
    }

    public static char toChineseChar(int value, boolean useBigChar) {
        if (value >= 0 && value <= 9) {
            if (!useBigChar) {
                return SMALL_DIGITS[value];
            }
            return BIG_DIGITS[value];
        }
        throw new IllegalArgumentException("整型参数值\"" + value + "\"必须在0-9之间！");
    }

    public static boolean isValidChineseDigit(char value) {
        try {
            valueOf(value);
            return true;
        } catch (NotValidChineseDigitException unused) {
            return false;
        }
    }

    public Object clone() {
        return new ChineseDigit(this.digit);
    }

    public boolean equals(Object o) {
        if (o == this) {
            return true;
        }
        if (!(o instanceof ChineseDigit)) {
            return false;
        }
        ChineseDigit value = (ChineseDigit) o;
        return this.digit == value.digit;
    }

    public int hashCode() {
        int result = super.hashCode();
        int hc1 = this.digit;
        return (37 * result) + hc1;
    }

    public String toString() {
        return String.valueOf(chineseValue(false));
    }

    @Override // java.lang.Comparable
    public int compareTo(Object o) {
        ChineseDigit value = (ChineseDigit) o;
        return this.digit - value.digit;
    }
}
